@@ -1,6 +1,6 @@
 /* A sort of clone of the cddlib test program `lcdd'.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -138,7 +138,7 @@ pip_display_sol(std::ostream& out,
           << " = " << *i << endl;
     }
     const Constraint_System &constraints = pip->constraints();
-    bool constraints_empty = constraints.empty();
+    const bool constraints_empty = constraints.empty();
     if (!constraints_empty) {
       out << setw(indent*2) << "" << "if ";
       for (Constraint_System::const_iterator
@@ -148,7 +148,7 @@ pip_display_sol(std::ostream& out,
         out << ((i == cs_begin) ? "" : " and ") << *i;
       out << " then" << endl;
     }
-    const PIP_Decision_Node* decision_node_p = pip->as_decision();
+    const PIP_Decision_Node* const decision_node_p = pip->as_decision();
     if (decision_node_p) {
       pip_display_sol(out, decision_node_p->child_node(true),
                       parameters, vars, space_dimension, indent+1);
@@ -157,7 +157,7 @@ pip_display_sol(std::ostream& out,
                       parameters, vars, space_dimension, indent+1);
     }
     else {
-      const PIP_Solution_Node* solution_node_p = pip->as_solution();
+      const PIP_Solution_Node* const solution_node_p = pip->as_solution();
       out << setw(indent*2 + (constraints_empty ? 0 : 2)) << "" << "{";
       for (Variables_Set::const_iterator
              v_begin = vars.begin(),
@@ -282,6 +282,7 @@ public:
       std::istringstream iss(line);
       iss >> bignum_column_coding;
     }
+    PPL_ASSERT(bignum_column_coding >= -1);
 
     PPL::dimension_type num_constraints;
     PPL::dimension_type constraint_width;
@@ -305,15 +306,16 @@ public:
       }
     }
 
-    PPL::dimension_type bignum_column = (bignum_column_coding == -1)
+    const PPL::dimension_type bignum_column
+      = (bignum_column_coding == -1)
       ? PPL::not_a_dimension()
-      : (num_vars + (bignum_column_coding - 1));
+      : (num_vars + PPL::dimension_type(bignum_column_coding - 1));
 
-    bool result = update_pip(num_vars, num_params,
-                             num_constraints, num_ctx_rows,
-                             constraints, context,
-                             constraint_type, ctx_type,
-                             bignum_column);
+    const bool result = update_pip(num_vars, num_params,
+                                   num_constraints, num_ctx_rows,
+                                   constraints, context,
+                                   constraint_type, ctx_type,
+                                   bignum_column);
     return result;
   }
 
@@ -349,9 +351,11 @@ public:
 
     int bignum_column_coding;
     in >> bignum_column_coding;
-    PPL::dimension_type bignum_column = (bignum_column_coding == -1)
+    PPL_ASSERT(bignum_column_coding >= -1);
+    const PPL::dimension_type bignum_column
+      = (bignum_column_coding == -1)
       ? PPL::not_a_dimension()
-      : (bignum_column_coding - 1);
+      : PPL::dimension_type(bignum_column_coding - 1);
 
     int solve_integer;
     in >> solve_integer;
@@ -362,7 +366,7 @@ public:
 
     if (!expect(in, '('))
       return false;
-    PPL::dimension_type constraint_width = num_vars+num_params+1;
+    const PPL::dimension_type constraint_width = num_vars+num_params+1;
     Coeff_Vector constraints(num_constraints * constraint_width);
     Int_Vector constraint_type(num_constraints);
     for (PPL::dimension_type i = 0; i < num_constraints; ++i)
@@ -379,11 +383,11 @@ public:
       if (!read_vector(in, i, num_params+1, num_params, context))
         return false;
 
-    bool result = update_pip(num_vars, num_params,
-                             num_constraints, num_ctx_rows,
-                             constraints, context,
-                             constraint_type, ctx_type,
-                             bignum_column);
+    const bool result = update_pip(num_vars, num_params,
+                                   num_constraints, num_ctx_rows,
+                                   constraints, context,
+                                   constraint_type, ctx_type,
+                                   bignum_column);
     return result;
   }
 
@@ -427,7 +431,7 @@ protected:
     if (in.fail())
       return false;
     std::istringstream iss(s);
-    PPL::dimension_type start_index = row_index * row_size;
+    const PPL::dimension_type start_index = row_index * row_size;
     PPL::dimension_type k = start_index;
     for (PPL::dimension_type i = 0; i < cst_col; ++i, ++k) {
       iss >> tab[k];
@@ -559,8 +563,8 @@ set_output(const char* file_name) {
 
   if (file_name) {
     output_stream_p = new std::ofstream(file_name,
-					std::ios_base::out
-					| std::ios_base::app);
+                                        std::ios_base::out
+                                        | std::ios_base::app);
     if (!*output_stream_p)
       fatal("cannot open output file `%s'", file_name);
     output_file_name = file_name;
@@ -625,10 +629,10 @@ process_options(int argc, char* argv[]) {
   while (true) {
 #ifdef PPL_HAVE_GETOPT_H
     int option_index = 0;
-    int c = getopt_long(argc, argv, OPTION_LETTERS, long_options,
-			&option_index);
+    const int c = getopt_long(argc, argv, OPTION_LETTERS, long_options,
+                        &option_index);
 #else
-    int c = getopt(argc, argv, OPTION_LETTERS);
+    const int c = getopt(argc, argv, OPTION_LETTERS);
 #endif
 
     if (c == EOF)
@@ -647,14 +651,14 @@ process_options(int argc, char* argv[]) {
 
     case 'R':
       {
-        const int MEGA = 1024*1024;
-        long l = strtol(optarg, &endptr, 10);
+        const unsigned long MEGA = 1024U*1024U;
+        const long l = strtol(optarg, &endptr, 10);
         if (*endptr || l < 0)
           fatal("a non-negative integer must follow `-R'");
         else if (static_cast<unsigned long>(l) > ULONG_MAX/MEGA)
           max_bytes_of_virtual_memory = ULONG_MAX;
         else
-          max_bytes_of_virtual_memory = l*MEGA;
+          max_bytes_of_virtual_memory = static_cast<unsigned long>(l)*MEGA;
       }
       break;
 
@@ -681,7 +685,7 @@ process_options(int argc, char* argv[]) {
     case 'i':
       loop_iterations = strtol(optarg, &endptr, 10);
       if (*endptr || loop_iterations < 1)
-	fatal("a positive integer must follow `-i'");
+        fatal("a positive integer must follow `-i'");
       break;
 
 #if defined(USE_PPL)
@@ -756,12 +760,12 @@ main(int argc, char* argv[]) try {
 #if defined(USE_PPL)
   if (strcmp(PPL_VERSION, PPL::version()) != 0)
     fatal("was compiled with PPL version %s, but linked with version %s",
-	  PPL_VERSION, PPL::version());
+          PPL_VERSION, PPL::version());
 
   if (verbose)
     std::cerr << "Parma Polyhedra Library version:\n" << PPL::version()
-	      << "\n\nParma Polyhedra Library banner:\n" << PPL::banner()
-	      << std::endl;
+              << "\n\nParma Polyhedra Library banner:\n" << PPL::banner()
+              << std::endl;
 #endif
 
   // Process command line options.
