@@ -1,6 +1,6 @@
 /* PPL Java interface: domain-independent functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -21,7 +21,7 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
-#include "ppl_java_common.defs.hh"
+#include "ppl_java_common_defs.hh"
 #include "parma_polyhedra_library_Artificial_Parameter.h"
 #include "parma_polyhedra_library_Artificial_Parameter_Sequence.h"
 #include "parma_polyhedra_library_Bounded_Integer_Type_Overflow.h"
@@ -388,7 +388,7 @@ Java_parma_1polyhedra_1library_Linear_1Expression_1Coefficient_initIDs
   cached_FMIDs.Linear_Expression_Coefficient_coeff_ID = fID;
   jmethodID mID;
   mID = env->GetMethodID(j_le_coeff_class, "<init>",
-			 "(Lparma_polyhedra_library/Coefficient;)V");
+                         "(Lparma_polyhedra_library/Coefficient;)V");
   CHECK_RESULT_ASSERT(env, mID);
   cached_FMIDs.Linear_Expression_Coefficient_init_ID = mID;
 }
@@ -456,10 +456,10 @@ Java_parma_1polyhedra_1library_Linear_1Expression_1Variable_initIDs
 (JNIEnv* env, jclass j_le_var_class) {
   jmethodID mID;
   mID = env->GetMethodID(j_le_var_class, "<init>",
-			 "(Lparma_polyhedra_library/Variable;)V");
+                         "(Lparma_polyhedra_library/Variable;)V");
   CHECK_RESULT_ASSERT(env, mID);
   cached_FMIDs.Linear_Expression_Variable_init_ID = mID;
-  mID = env->GetMethodID(j_le_var_class, "var_id", "()I");
+  mID = env->GetMethodID(j_le_var_class, "var_id", "()J");
   CHECK_RESULT_ASSERT(env, mID);
   cached_FMIDs.Linear_Expression_Variable_var_id_ID = mID;
 }
@@ -675,10 +675,14 @@ Java_parma_1polyhedra_1library_Bounded_1Integer_1Type_1Width_initIDs
 JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Variable_initIDs
 (JNIEnv* env, jclass j_variable_class) {
-  jfieldID fID = env->GetFieldID(j_variable_class, "varid", "I");
+  jfieldID fID = env->GetFieldID(j_variable_class, "varid", "J");
   CHECK_RESULT_ASSERT(env, fID);
   cached_FMIDs.Variable_varid_ID = fID;
-  jmethodID mID = env->GetMethodID(j_variable_class, "<init>", "(I)V");
+  fID = env->GetStaticFieldID(j_variable_class, "stringifier",
+                              "Lparma_polyhedra_library/Variable_Stringifier;");
+  CHECK_RESULT_ASSERT(env, fID);
+  cached_FMIDs.Variable_stringifier_ID = fID;
+  jmethodID mID = env->GetMethodID(j_variable_class, "<init>", "(J)V");
   CHECK_RESULT_ASSERT(env, mID);
   cached_FMIDs.Variable_init_ID = mID;
 }
@@ -820,16 +824,20 @@ Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_reset_1timeout
 
 JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_set_1deterministic_1timeout
-(JNIEnv* env, jclass, jint weight) {
+(JNIEnv* env, jclass, jint unscaled_weight, jint scale) {
   try {
     // In case a timeout was already set.
     reset_deterministic_timeout();
-    assert(weight > 0);
-    unsigned cxx_weight = jtype_to_unsigned<unsigned>(weight);
-    assert(cxx_weight > 0);
+    // Note: let `unscaled_weight == 0' result in an exception.
+    assert(unscaled_weight >= 0 && scale >= 0);
+    unsigned long cxx_unscaled_weight
+      = jtype_to_unsigned<unsigned long>(unscaled_weight);
+    unsigned cxx_scale = jtype_to_unsigned<unsigned>(scale);
     static deterministic_timeout_exception e;
+    typedef Parma_Polyhedra_Library::Weightwatch_Traits Traits;
     p_deterministic_timeout_object
-      = new Weightwatch(cxx_weight, abandon_expensive_computations, e);
+      = new Weightwatch(Traits::compute_delta(cxx_unscaled_weight, cxx_scale),
+                        abandon_expensive_computations, e);
   }
   CATCH_ALL;
 }
@@ -962,7 +970,7 @@ Java_parma_1polyhedra_1library_MIP_1Problem_constraints
     MIP_Problem* mip
       = reinterpret_cast<MIP_Problem*>(get_ptr(env, j_this_mip_problem));
     for (MIP_Problem::const_iterator cs_it = mip->constraints_begin(),
-	   cs_end = mip->constraints_end(); cs_it != cs_end; ++cs_it) {
+           cs_end = mip->constraints_end(); cs_it != cs_end; ++cs_it) {
       jobject j_constraint = build_java_constraint(env, *cs_it);
       env->CallBooleanMethod(j_cs,
                              cached_FMIDs.Constraint_System_add_ID,
@@ -1247,6 +1255,44 @@ Java_parma_1polyhedra_1library_MIP_1Problem_ascii_1dump
   return 0;
 }
 
+JNIEXPORT jstring JNICALL
+Java_parma_1polyhedra_1library_Variable_toString
+(JNIEnv* env, jobject j_this) {
+  using namespace Parma_Polyhedra_Library::IO_Operators;
+  Variable ppl_var = build_cxx_variable(env, j_this);
+  std::ostringstream s;
+  s << ppl_var;
+  return env->NewStringUTF(s.str().c_str());
+}
+
+JNIEXPORT void JNICALL
+Java_parma_1polyhedra_1library_Variable_setStringifier
+(JNIEnv* env, jclass j_variable_class, jobject j_stringifier) {
+  // Store j_stringifier in the corresponding static field.
+  env->SetStaticObjectField(j_variable_class,
+                            cached_FMIDs.Variable_stringifier_ID,
+                            j_stringifier);
+  if (j_stringifier == NULL) {
+    // No stringifier object: reset cache values.
+    cached_classes.Variable_Stringifier = NULL;
+    cached_FMIDs.Variable_Stringifier_stringify_ID = NULL;
+    // Reset default C++ output function.
+    Variable::set_output_function(&Variable::default_output_function);
+  }
+  else {
+    // Update cache with values computed for concrete class.
+    jclass vs_class = env->GetObjectClass(j_stringifier);
+    CHECK_RESULT_ASSERT(env, vs_class);
+    cached_classes.Variable_Stringifier = vs_class;
+    jmethodID mID = env->GetMethodID(vs_class, "stringify",
+                                     "(J)Ljava/lang/String;");
+    CHECK_RESULT_ASSERT(env, mID);
+    cached_FMIDs.Variable_Stringifier_stringify_ID = mID;
+    // Set C++ output function to the Java wrapper.
+    Variable::set_output_function(&Java_Variable_output_function);
+  }
+}
+
 JNIEXPORT jstring JNICALL
 Java_parma_1polyhedra_1library_Linear_1Expression_toString
 (JNIEnv* env, jobject j_this) {
