@@ -1,6 +1,6 @@
 /* CO_Tree class implementation.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,7 +22,7 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "CO_Tree.defs.hh"
+#include "CO_Tree_defs.hh"
 
 namespace PPL = Parma_Polyhedra_Library;
 
@@ -63,7 +63,8 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1) {
     --candidate2_index;
     while (indexes[candidate2_index] == unused_index)
       --candidate2_index;
-  } else {
+  }
+  else {
     ++candidate2_index;
     while (indexes[candidate2_index] == unused_index)
       ++candidate2_index;
@@ -91,7 +92,8 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1) {
     // candidate1_node.
     return iterator(insert_precise(key1, Coefficient_zero(),
                                    candidate1_node));
-  } else {
+  }
+  else {
     PPL_ASSERT(candidate1_node.depth() < candidate2_node.depth());
     // candidate2_node is deeper in the tree than candidate1_node, so use
     // candidate2_node.
@@ -126,7 +128,8 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1,
     --candidate2_index;
     while (indexes[candidate2_index] == unused_index)
       --candidate2_index;
-  } else {
+  }
+  else {
     ++candidate2_index;
     while (indexes[candidate2_index] == unused_index)
       ++candidate2_index;
@@ -150,7 +153,8 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1,
     // candidate1_node is deeper in the tree than candidate2_node, so
     // use candidate1_node.
     return iterator(insert_precise(key1, data1, candidate1_node));
-  } else {
+  }
+  else {
     PPL_ASSERT(candidate1_node.depth() < candidate2_node.depth());
     // candidate2_node is deeper in the tree than candidate1_node, so
     // use candidate2_node.
@@ -163,9 +167,9 @@ PPL::CO_Tree::erase_element_and_shift_left(dimension_type key) {
   iterator itr = erase(key);
   if (itr == end())
     return;
-  dimension_type i = dfs_index(itr);
+  const dimension_type i = dfs_index(itr);
   dimension_type* p = indexes + i;
-  dimension_type* p_end = indexes + (reserved_size + 1);
+  const dimension_type* const p_end = indexes + (reserved_size + 1);
   for ( ; p != p_end; ++p)
     if (*p != unused_index)
       --(*p);
@@ -214,7 +218,8 @@ PPL::CO_Tree::bisect_in(dimension_type first, dimension_type last,
 
       last = half;
 
-    } else {
+    }
+    else {
 
       ++new_half;
       while (indexes[new_half] == unused_index)
@@ -259,7 +264,8 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
         // The searched element is in (hint,new_hint) and both indexes point
         // to valid elements.
         break;
-      } else
+      }
+      else
         new_hint = hint - offset;
 
       PPL_ASSERT(new_hint > 0);
@@ -286,7 +292,8 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
       offset *= 2;
     }
 
-  } else {
+  }
+  else {
     // The searched element is after `hint'.
     while (true) {
 
@@ -301,7 +308,8 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
         // The searched element is in (hint,new_hint) and both indexes point
         // to valid elements.
         break;
-      } else
+      }
+      else
         new_hint = hint + offset;
 
       PPL_ASSERT(new_hint > 0);
@@ -357,54 +365,69 @@ PPL::CO_Tree::insert_precise(dimension_type key1,
   PPL_ASSERT(!empty());
 
 #ifndef NDEBUG
+  // Check that `itr' is a correct hint.
   tree_iterator itr2(*this);
   itr2.go_down_searching_key(key1);
   PPL_ASSERT(itr == itr2);
 #endif
 
   if (itr.index() == key1) {
+    // Replacement, rather than insertion.
     *itr = data1;
     PPL_ASSERT(OK());
     return itr;
   }
 
-  if (data <= &data1 && &data1 < data + (reserved_size + 1)) {
-    // data1 is a coefficient of this row.
-    // Avoid invalidating it.
-    data_type x = data1;
+  // Proper insertion: check if it would invalidate `data1'.
+  const bool invalidating
+    = (data <= &data1) && (&data1 < data + (reserved_size + 1));
+
+  if (!invalidating)
+    return insert_precise_aux(key1, data1, itr);
+
+  // `data1' could be invalidated by the insert, because it is
+  // a coefficient of this row. Avoid the issue by copying it.
+  data_type data1_copy = data1;
 
 #ifndef NDEBUG
-    dimension_type i = &data1 - data;
-    dimension_type key2 = indexes[i];
-    PPL_ASSERT(key2 != unused_index);
-    // This is true since key1 is not in the tree.
-    PPL_ASSERT(key2 != key1);
+  dimension_type i = &data1 - data;
+  dimension_type key2 = indexes[i];
+  PPL_ASSERT(key2 != unused_index);
+  // This is true since `key1' is not in the tree.
+  PPL_ASSERT(key2 != key1);
 #endif
 
-    // Insert a dummy coefficient.
-    // NOTE: This may invalidate data1, because it may reallocate the tree
-    // and/or move coefficients during rebalancing).
-    itr = insert_precise(key1, Coefficient_zero(), itr);
+  // Insert a dummy coefficient.
+  // NOTE: this may invalidate `data1', because it may reallocate the tree
+  // and/or move coefficients during rebalancing.
+  itr = insert_precise_aux(key1, Coefficient_zero(), itr);
 
-    PPL_ASSERT(itr.index() == key1);
+  PPL_ASSERT(itr.index() == key1);
 
-    using std::swap;
+  // Swap the correct coefficient in place.
+  using std::swap;
+  swap(*itr, data1_copy);
 
-    // Swap the correct coefficient in place.
-    swap(*itr, x);
+  PPL_ASSERT(OK());
+  return itr;
+}
 
-    PPL_ASSERT(OK());
-    return itr;
-  }
+PPL::CO_Tree::tree_iterator
+PPL::CO_Tree::insert_precise_aux(dimension_type key1,
+                                 data_type_const_reference data1,
+                                 tree_iterator itr) {
+  PPL_ASSERT(key1 != unused_index);
+  PPL_ASSERT(!empty());
+  // This is a proper insert.
+  PPL_ASSERT(itr.index() != key1);
+  // `data1' is not going to be invalidated.
+  PPL_ASSERT(!(data <= &data1 && &data1 < data + (reserved_size + 1)));
 
   if (is_greater_than_ratio(size_ + 1, reserved_size, max_density_percent)) {
-
     rebuild_bigger_tree();
-
-    // itr was invalidated by the rebuild operation
+    // `itr' was invalidated by the rebuild operation
     itr.get_root();
     itr.go_down_searching_key(key1);
-
     PPL_ASSERT(itr.index() != key1);
   }
 
@@ -423,13 +446,10 @@ PPL::CO_Tree::insert_precise(dimension_type key1,
     new (&(*itr)) data_type(data1);
     // Set the index only if the construction was successful.
     itr.index() = key1;
-
-  } else {
-
+  }
+  else {
     itr = rebalance(itr, key1, data1);
-
     itr.go_down_searching_key(key1);
-
     PPL_ASSERT(itr.index() == key1);
   }
   PPL_ASSERT(OK());
@@ -536,17 +556,16 @@ PPL::CO_Tree::erase(tree_iterator itr) {
 }
 
 void
-PPL::CO_Tree::init(dimension_type reserved_size1) {
-  if (reserved_size1 == 0) {
-    indexes = NULL;
-    data = NULL;
-    size_ = 0;
-    reserved_size = 0;
-    max_depth = 0;
-  }
-  else {
-    init(0);
-    const dimension_type new_max_depth = integer_log2(reserved_size1) + 1;
+PPL::CO_Tree::init(dimension_type n) {
+  indexes = NULL;
+  data = NULL;
+  size_ = 0;
+  reserved_size = 0;
+  max_depth = 0;
+
+  if (n > 0) {
+    const dimension_type max_d = integer_log2(n) + 1;
+    const height_t new_max_depth = static_cast<height_t>(max_d);
     const dimension_type new_reserved_size
       = (static_cast<dimension_type>(1) << new_max_depth) - 1;
     // If this throws, *this will be the empty tree.
@@ -631,11 +650,12 @@ PPL::CO_Tree::structure_OK() const {
     if (itr.index() != unused_index)
       return false;
 
-  } else {
+  }
+  else {
     // This const_cast could be removed by adding a const_tree_iterator,
     // but it would add much code duplication without a real need.
     tree_iterator itr(*const_cast<CO_Tree*>(this));
-    dimension_type real_size = count_used_in_subtree(itr);
+    const dimension_type real_size = count_used_in_subtree(itr);
     if (real_size != size_)
       // There are \p real_size elements in the tree that are reachable by the
       // root, but size is \p size.
@@ -734,9 +754,9 @@ PPL::CO_Tree::rebuild_bigger_tree() {
     return;
   }
 
-  dimension_type new_reserved_size = reserved_size*2 + 1;
+  const dimension_type new_reserved_size = reserved_size*2 + 1;
 
-  dimension_type* new_indexes = new dimension_type[new_reserved_size + 2];
+  dimension_type* const new_indexes = new dimension_type[new_reserved_size + 2];
 
   data_type* new_data;
 
@@ -787,7 +807,7 @@ PPL::CO_Tree::rebalance(tree_iterator itr, dimension_type key,
   }
   PPL_ASSERT(itr.index() == unused_index || itr.is_leaf());
   height_t itr_depth_minus_1 = itr.depth() - 1;
-  height_t height = max_depth - itr_depth_minus_1;
+  const height_t height = max_depth - itr_depth_minus_1;
   dimension_type subtree_size;
   dimension_type subtree_reserved_size = (static_cast<dimension_type>(1)
                                           << height) - 1;
@@ -813,7 +833,7 @@ PPL::CO_Tree::rebalance(tree_iterator itr, dimension_type key,
     // The density in the tree is correct, so the while condition is always
     // false for the root.
     PPL_ASSERT(itr_depth_minus_1 != 0);
-    bool is_right_brother = itr.is_right_child();
+    const bool is_right_brother = itr.is_right_child();
     itr.get_parent();
     if (is_right_brother)
       itr.get_left_child();
@@ -833,10 +853,10 @@ PPL::CO_Tree::rebalance(tree_iterator itr, dimension_type key,
 
   // Step 1: compact elements of this subtree in the rightmost end, from right
   //         to left.
-  dimension_type last_index_in_subtree
+  const dimension_type last_index_in_subtree
     = itr.dfs_index() + itr.get_offset() - 1;
 
-  dimension_type first_unused
+  const dimension_type first_unused
     = compact_elements_in_the_rightmost_end(last_index_in_subtree,
                                             subtree_size, key, value,
                                             !deleting);
@@ -894,7 +914,8 @@ PPL::CO_Tree
           --first_unused_data;
         }
         break;
-      } else {
+      }
+      else {
         if (last_index_in_subtree != first_unused_index) {
           PPL_ASSERT(first_unused_index != indexes);
           PPL_ASSERT(last_index_in_subtree != indexes);
@@ -933,7 +954,7 @@ PPL::CO_Tree
     --subtree_size;
   }
 
-  ptrdiff_t distance = first_unused_index - indexes;
+  const ptrdiff_t distance = first_unused_index - indexes;
   PPL_ASSERT(distance >= 0);
   return static_cast<dimension_type>(distance);
 }
@@ -990,7 +1011,8 @@ PPL::CO_Tree::redistribute_elements_in_subtree(
         new (&(data[top_i])) data_type(value);
         // Set the index only if the construction was successful.
         indexes[top_i] = key;
-      } else {
+      }
+      else {
         if (last_used != top_i) {
           PPL_ASSERT(indexes[top_i] == unused_index);
           indexes[top_i] = indexes[last_used];
@@ -999,7 +1021,8 @@ PPL::CO_Tree::redistribute_elements_in_subtree(
         }
         ++last_used;
       }
-    } else {
+    }
+    else {
       PPL_ASSERT(stack_first_empty + 2
                  < stack + sizeof(stack)/sizeof(stack[0]));
 
@@ -1108,7 +1131,8 @@ PPL::CO_Tree::move_data_from(CO_Tree& tree) {
 
     if (top_n == 0) {
       --stack_first_empty;
-    } else {
+    }
+    else {
       if (top_n == 1) {
         PPL_ASSERT(root.index() == unused_index);
         PPL_ASSERT(tree.indexes[source_index] != unused_index);
@@ -1120,7 +1144,8 @@ PPL::CO_Tree::move_data_from(CO_Tree& tree) {
         while (tree.indexes[source_index] == unused_index)
           ++source_index;
         --stack_first_empty;
-      } else {
+      }
+      else {
         PPL_ASSERT(stack_first_empty + 3 < sizeof(stack)/sizeof(stack[0]));
 
         const dimension_type half = (top_n + 1) / 2;
@@ -1156,7 +1181,8 @@ PPL::CO_Tree::copy_data_from(const CO_Tree& x) {
       if (x.indexes[i] != unused_index) {
         indexes[i] = x.indexes[i];
         new (&(data[i])) data_type(x.data[i]);
-      } else {
+      }
+      else {
         PPL_ASSERT(indexes[i] == unused_index);
       }
   } catch (...) {
@@ -1194,7 +1220,8 @@ PPL::CO_Tree::count_used_in_subtree(tree_iterator itr) {
 
   PPL_ASSERT(root_index > (k - 1));
 
-  dimension_type* current_index = &(itr.tree.indexes[root_index - (k - 1)]);
+  const dimension_type* current_index
+    = &(itr.tree.indexes[root_index - (k - 1)]);
 
   for (dimension_type j = 2*k - 1; j > 0; --j, ++current_index)
     if (*current_index != unused_index)
@@ -1211,12 +1238,14 @@ PPL::CO_Tree::const_iterator::OK() const {
       return false;
     if (current_data != 0)
       return false;
-  } else
+  }
+  else
     if (tree->reserved_size == 0) {
       if (current_index != 1 + static_cast<dimension_type*>(0)
           || current_data != 1 + static_cast<data_type*>(0))
         return false;
-    } else {
+    }
+    else {
       if (current_index <= &(tree->indexes[0]))
         return false;
       if (current_index > &(tree->indexes[tree->reserved_size + 1]))
@@ -1242,12 +1271,14 @@ PPL::CO_Tree::iterator::OK() const {
       return false;
     if (current_data != 0)
       return false;
-  } else
+  }
+  else
     if (tree->reserved_size == 0) {
       if (current_index != 1 + static_cast<dimension_type*>(0)
           || current_data != 1 + static_cast<data_type*>(0))
         return false;
-    } else {
+    }
+    else {
       if (current_index <= &(tree->indexes[0]))
         return false;
       if (current_index > &(tree->indexes[tree->reserved_size + 1]))
@@ -1271,7 +1302,7 @@ PPL::CO_Tree::tree_iterator::OK() const {
     return false;
 
   // This assumes two's complement encoding.
-  dimension_type correct_offset = i & -i;
+  const dimension_type correct_offset = i & -i;
 
   if (offset != correct_offset)
     return false;
@@ -1294,7 +1325,8 @@ PPL::CO_Tree::tree_iterator::go_down_searching_key(dimension_type key) {
         get_parent();
         break;
       }
-    } else {
+    }
+    else {
       get_right_child();
       if (index() == unused_index) {
         get_parent();
