@@ -1,6 +1,6 @@
 /* Generator class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,10 +22,10 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "Generator.defs.hh"
-#include "Variable.defs.hh"
-#include "Variables_Set.defs.hh"
-#include "math_utilities.defs.hh"
+#include "Generator_defs.hh"
+#include "Variable_defs.hh"
+#include "Variables_Set_defs.hh"
+#include "math_utilities_defs.hh"
 
 #include <iostream>
 #include <sstream>
@@ -35,8 +35,8 @@ namespace PPL = Parma_Polyhedra_Library;
 
 void
 PPL::Generator::throw_dimension_incompatible(const char* method,
-					     const char* v_name,
-					     const Variable v) const {
+                                             const char* v_name,
+                                             const Variable v) const {
   std::ostringstream s;
   s << "PPL::Generator::" << method << ":" << std::endl
     << "this->space_dimension() == " << space_dimension() << ", "
@@ -46,7 +46,7 @@ PPL::Generator::throw_dimension_incompatible(const char* method,
 
 void
 PPL::Generator::throw_invalid_argument(const char* method,
-				       const char* reason) const {
+                                       const char* reason) const {
   std::ostringstream s;
   s << "PPL::Generator::" << method << ":" << std::endl
     << reason << ".";
@@ -88,11 +88,11 @@ PPL::Generator::point(Representation r) {
 
 PPL::Generator
 PPL::Generator::closure_point(const Linear_Expression& e,
-			      Coefficient_traits::const_reference d,
+                              Coefficient_traits::const_reference d,
                               Representation r) {
   if (d == 0)
     throw std::invalid_argument("PPL::closure_point(e, d):\n"
-				"d == 0.");
+                                "d == 0.");
   Linear_Expression ec(e, r);
   ec.set_inhomogeneous_term(d);
 
@@ -125,11 +125,11 @@ PPL::Generator::ray(const Linear_Expression& e, Representation r) {
   // The origin of the space cannot be a ray.
   if (e.all_homogeneous_terms_are_zero())
     throw std::invalid_argument("PPL::ray(e):\n"
-				"e == 0, but the origin cannot be a ray.");
+                                "e == 0, but the origin cannot be a ray.");
 
   Linear_Expression ec(e, r);
   ec.set_inhomogeneous_term(0);
-  Generator g(ec, Generator::RAY, NECESSARILY_CLOSED);
+  const Generator g(ec, Generator::RAY, NECESSARILY_CLOSED);
 
   return g;
 }
@@ -139,11 +139,11 @@ PPL::Generator::line(const Linear_Expression& e, Representation r) {
   // The origin of the space cannot be a line.
   if (e.all_homogeneous_terms_are_zero())
     throw std::invalid_argument("PPL::line(e):\n"
-				"e == 0, but the origin cannot be a line.");
+                                "e == 0, but the origin cannot be a line.");
 
   Linear_Expression ec(e, r);
   ec.set_inhomogeneous_term(0);
-  Generator g(ec, Generator::LINE, NECESSARILY_CLOSED);
+  const Generator g(ec, Generator::LINE, NECESSARILY_CLOSED);
 
   return g;
 }
@@ -172,7 +172,8 @@ PPL::Generator::remove_space_dimensions(const Variables_Set& vars) {
 
     PPL_ASSERT(OK());
     return false;
-  } else {
+  }
+  else {
     strong_normalize();
     PPL_ASSERT(OK());
     return true;
@@ -228,8 +229,8 @@ PPL::Generator::is_equivalent_to(const Generator& y) const {
     // Due to the presence of epsilon-coefficients, syntactically
     // different points may actually encode the same generator.
     // First, drop the epsilon-coefficient ...
-    Linear_Expression x_expr(x);
-    Linear_Expression y_expr(y);
+    Linear_Expression x_expr(x.expression());
+    Linear_Expression y_expr(y.expression());
     // ... second, re-normalize ...
     x_expr.normalize();
     y_expr.normalize();
@@ -291,7 +292,7 @@ PPL::Generator::fancy_print(std::ostream& s) const {
     bool needed_divisor = false;
   bool extra_parentheses = false;
   const dimension_type num_variables = space_dimension();
-  Generator::Type t = type();
+  const Generator::Type t = type();
   switch (t) {
   case Generator::LINE:
     s << "l(";
@@ -378,9 +379,9 @@ PPL::IO_Operators::operator<<(std::ostream& s, const Generator::Type& t) {
 bool
 PPL::Generator::is_matching_closure_point(const Generator& p) const {
   PPL_ASSERT(topology() == p.topology()
-	 && space_dimension() == p.space_dimension()
-	 && type() == CLOSURE_POINT
-	 && p.type() == POINT);
+         && space_dimension() == p.space_dimension()
+         && type() == CLOSURE_POINT
+         && p.type() == POINT);
   const Generator& cp = *this;
   if (cp.expr.inhomogeneous_term() == p.expr.inhomogeneous_term()) {
     // Divisors are equal: we can simply compare coefficients
@@ -414,8 +415,8 @@ PPL::Generator::OK() const {
   if (is_not_necessarily_closed() && expr.space_dimension() == 0) {
 #ifndef NDEBUG
     std::cerr << "Generator has fewer coefficients than the minimum "
-	      << "allowed by its topology."
-	      << std::endl;
+              << "allowed by its topology."
+              << std::endl;
 #endif
     return false;
   }
@@ -426,7 +427,7 @@ PPL::Generator::OK() const {
   if (tmp != *this) {
 #ifndef NDEBUG
     std::cerr << "Generators should be strongly normalized!"
-	      << std::endl;
+              << std::endl;
 #endif
     return false;
   }
@@ -438,15 +439,15 @@ PPL::Generator::OK() const {
     if (expr.inhomogeneous_term() != 0) {
 #ifndef NDEBUG
       std::cerr << "Lines must have a zero inhomogeneous term!"
-		<< std::endl;
+                << std::endl;
 #endif
       return false;
     }
     if (!is_necessarily_closed() && epsilon_coefficient() != 0) {
 #ifndef NDEBUG
       std::cerr << "Lines and rays must have a zero coefficient "
-		<< "for the epsilon dimension!"
-		<< std::endl;
+                << "for the epsilon dimension!"
+                << std::endl;
 #endif
       return false;
     }
@@ -455,7 +456,7 @@ PPL::Generator::OK() const {
     if (expr.all_homogeneous_terms_are_zero()) {
 #ifndef NDEBUG
       std::cerr << "The origin of the vector space cannot be a line or a ray!"
-		<< std::endl;
+                << std::endl;
 #endif
       return false;
     }
@@ -465,17 +466,17 @@ PPL::Generator::OK() const {
     if (expr.inhomogeneous_term() <= 0) {
 #ifndef NDEBUG
       std::cerr << "Points must have a positive divisor!"
-		<< std::endl;
+                << std::endl;
 #endif
       return false;
     }
     if (!is_necessarily_closed())
       if (epsilon_coefficient() <= 0) {
 #ifndef NDEBUG
-	std::cerr << "In the NNC topology, points must have epsilon > 0"
-		  << std::endl;
+        std::cerr << "In the NNC topology, points must have epsilon > 0"
+                  << std::endl;
 #endif
-	return false;
+        return false;
       }
     break;
 
@@ -483,7 +484,7 @@ PPL::Generator::OK() const {
     if (expr.inhomogeneous_term() <= 0) {
 #ifndef NDEBUG
       std::cerr << "Closure points must have a positive divisor!"
-		<< std::endl;
+                << std::endl;
 #endif
       return false;
     }
