@@ -1,7 +1,7 @@
 /* Grid class implementation
    (non-inline private or protected functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -23,10 +23,10 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "Grid.defs.hh"
-#include "Grid_Generator.defs.hh"
-#include "Scalar_Products.defs.hh"
-#include "Scalar_Products.inlines.hh"
+#include "Grid_defs.hh"
+#include "Grid_Generator_defs.hh"
+#include "Scalar_Products_defs.hh"
+#include "Scalar_Products_inlines.hh"
 #include "assert.hh"
 #include <string>
 #include <iostream>
@@ -50,7 +50,7 @@ namespace PPL = Parma_Polyhedra_Library;
 
 void
 PPL::Grid::construct(dimension_type num_dimensions,
-		     const Degenerate_Element kind) {
+                     const Degenerate_Element kind) {
   space_dim = num_dimensions;
 
   if (kind == EMPTY) {
@@ -191,7 +191,7 @@ PPL::Grid::quick_equivalence_test(const Grid& y) const {
     if (x.con_sys.num_rows() != y.con_sys.num_rows())
       return Grid::TVB_FALSE;
     //  - the same number of equalities; ...
-    dimension_type x_num_equalities = x.con_sys.num_equalities();
+    const dimension_type x_num_equalities = x.con_sys.num_equalities();
     if (x_num_equalities != y.con_sys.num_equalities())
       return Grid::TVB_FALSE;
     //  - and if there are no equalities, the same congruences.
@@ -212,9 +212,9 @@ PPL::Grid::quick_equivalence_test(const Grid& y) const {
     if (x_num_lines == 0) {
       // Check for syntactic identity.
       if (x.gen_sys == y.gen_sys)
-	return Grid::TVB_TRUE;
+        return Grid::TVB_TRUE;
       else
-	return Grid::TVB_FALSE;
+        return Grid::TVB_FALSE;
     }
   }
 
@@ -259,7 +259,7 @@ PPL::Grid::is_included_in(const Grid& y) const {
   const Grid_Generator_System& gs = x.gen_sys;
   const Congruence_System& cgs = y.con_sys;
 
-  dimension_type num_rows = gs.num_rows();
+  const dimension_type num_rows = gs.num_rows();
   for (dimension_type i = num_rows; i-- > 0; )
     if (!cgs.satisfies_all_congruences(gs[i]))
       return false;
@@ -270,7 +270,7 @@ PPL::Grid::is_included_in(const Grid& y) const {
 
 bool
 PPL::Grid::bounds(const Linear_Expression& expr,
-		  const char* method_call) const {
+                  const char* method_call) const {
   // The dimension of `expr' must be at most the dimension of *this.
   if (space_dim < expr.space_dimension())
     throw_dimension_incompatible(method_call, "e", expr);
@@ -301,8 +301,8 @@ PPL::Grid::bounds_no_check(const Linear_Expression& expr) const {
     if (g.is_line_or_parameter()) {
       const int sp_sign = Scalar_Products::homogeneous_sign(expr, g);
       if (sp_sign != 0)
-	// `*this' does not bound `expr'.
-	return false;
+        // `*this' does not bound `expr'.
+        return false;
     }
   }
   return true;
@@ -339,7 +339,7 @@ PPL::Grid::frequency_no_check(const Linear_Expression& expr,
 
   // The frequency is the gcd of the scalar products of the parameters
   // in `gen_sys'.
-  dimension_type num_rows = gen_sys.num_rows();
+  const dimension_type num_rows = gen_sys.num_rows();
   PPL_DIRTY_TEMP_COEFFICIENT(sp);
   freq_n = 0;
 
@@ -389,9 +389,9 @@ PPL::Grid::frequency_no_check(const Linear_Expression& expr,
 
 bool
 PPL::Grid::max_min(const Linear_Expression& expr,
-		   const char* method_call,
-		   Coefficient& ext_n, Coefficient& ext_d, bool& included,
-		   Generator* point) const {
+                   const char* method_call,
+                   Coefficient& ext_n, Coefficient& ext_d, bool& included,
+                   Generator* point) const {
   if (bounds(expr, method_call)) {
     if (marked_empty())
       return false;
@@ -400,7 +400,7 @@ PPL::Grid::max_min(const Linear_Expression& expr,
       ext_d = 1;
       included = true;
       if (point != 0)
-	*point = Generator::point();
+        *point = Generator::point();
       return true;
     }
     // Grid::bounds above ensures the generators are up to date.
@@ -422,8 +422,10 @@ PPL::Grid::max_min(const Linear_Expression& expr,
     exact_div_assign(ext_d, ext_d, gcd);
 
     included = true;
-    if (point != 0)
-      *point = Generator::point(Linear_Expression(gen), gen.divisor());
+    if (point != 0) {
+      const Linear_Expression g_expr(gen.expression());
+      *point = Generator::point(g_expr, gen.divisor());
+    }
     return true;
   }
   return false;
@@ -524,25 +526,25 @@ PPL::Grid::minimize() const {
       Grid& gr = const_cast<Grid&>(*this);
       // Only one of the systems can be minimized here.
       if (congruences_are_minimized()) {
-	// Minimize the generator system.
-	gr.simplify(gr.gen_sys, gr.dim_kinds);
-	gr.set_generators_minimized();
+        // Minimize the generator system.
+        gr.simplify(gr.gen_sys, gr.dim_kinds);
+        gr.set_generators_minimized();
       }
       else {
 #ifndef NDEBUG
-	// Both systems are up to date, and the empty case is handled
-	// above, so the grid should contain points.
-	bool empty = simplify(gr.con_sys, gr.dim_kinds);
-	PPL_ASSERT(!empty);
+        // Both systems are up to date, and the empty case is handled
+        // above, so the grid should contain points.
+        bool empty = simplify(gr.con_sys, gr.dim_kinds);
+        PPL_ASSERT(!empty);
 #else
-	simplify(gr.con_sys, gr.dim_kinds);
+        simplify(gr.con_sys, gr.dim_kinds);
 #endif
-	gr.set_congruences_minimized();
-	if (!generators_are_minimized()) {
-	  // Minimize the generator system.
-	  gr.simplify(gr.gen_sys, gr.dim_kinds);
-	  gr.set_generators_minimized();
-	}
+        gr.set_congruences_minimized();
+        if (!generators_are_minimized()) {
+          // Minimize the generator system.
+          gr.simplify(gr.gen_sys, gr.dim_kinds);
+          gr.set_generators_minimized();
+        }
       }
     }
     else {
@@ -562,7 +564,7 @@ PPL::Grid::minimize() const {
 
 void
 PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
-			      Grid_Generator_System& gen_sys) {
+                              Grid_Generator_System& gen_sys) {
 #ifndef NDEBUG
   const dimension_type num_rows = gen_sys.num_rows();
 #endif
@@ -602,11 +604,11 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
 
 void
 PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
-			      Coefficient& divisor,
-			      const Grid_Generator* first_point) {
+                              Coefficient& divisor,
+                              const Grid_Generator* first_point) {
   PPL_ASSERT(divisor >= 0);
   if (sys.space_dimension() > 0 && divisor > 0) {
-    dimension_type num_rows = sys.num_rows();
+    const dimension_type num_rows = sys.num_rows();
 
     if (first_point != 0)
       lcm_assign(divisor, divisor, (*first_point).divisor());
@@ -615,17 +617,17 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
       // Move to the first point or parameter.
       dimension_type row = 0;
       while (sys[row].is_line())
-	if (++row == num_rows)
-	  // All rows are lines.
-	  return;
+        if (++row == num_rows)
+          // All rows are lines.
+          return;
 
       // Calculate the LCM of the given divisor and the divisor of
       // every point or parameter.
       while (row < num_rows) {
-	const Grid_Generator& g = sys[row];
-	if (g.is_parameter_or_point())
-	  lcm_assign(divisor, divisor, g.divisor());
-	++row;
+        const Grid_Generator& g = sys[row];
+        if (g.is_parameter_or_point())
+          lcm_assign(divisor, divisor, g.divisor());
+        ++row;
       }
     }
 
@@ -683,7 +685,7 @@ PPL::Grid::add_constraint_no_check(const Constraint& c) {
   }
 
   PPL_ASSERT(c.is_equality());
-  Congruence cg(c);
+  const Congruence cg(c);
   add_congruence_no_check(cg);
 }
 
@@ -693,7 +695,7 @@ PPL::Grid::refine_no_check(const Constraint& c) {
   PPL_ASSERT(space_dim >= c.space_dimension());
 
   if (c.is_equality()) {
-    Congruence cg(c);
+    const Congruence cg(c);
     add_congruence_no_check(cg);
   }
   else if (c.is_inconsistent())
@@ -710,8 +712,8 @@ PPL::Grid::throw_invalid_argument(const char* method, const char* reason) {
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* other_name,
-					dimension_type other_dim) const {
+                                        const char* other_name,
+                                        dimension_type other_dim) const {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":\n"
     << "this->space_dimension() == " << space_dimension() << ", "
@@ -721,71 +723,71 @@ PPL::Grid::throw_dimension_incompatible(const char* method,
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* gr_name,
-					const Grid& gr) const {
+                                        const char* gr_name,
+                                        const Grid& gr) const {
   throw_dimension_incompatible(method, gr_name, gr.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* le_name,
-					const Linear_Expression& le) const {
+                                        const char* le_name,
+                                        const Linear_Expression& le) const {
   throw_dimension_incompatible(method, le_name, le.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* cg_name,
-					const Congruence& cg) const {
+                                        const char* cg_name,
+                                        const Congruence& cg) const {
   throw_dimension_incompatible(method, cg_name, cg.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* c_name,
-					const Constraint& c) const {
+                                        const char* c_name,
+                                        const Constraint& c) const {
   throw_dimension_incompatible(method, c_name, c.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* g_name,
-					const Grid_Generator& g) const {
+                                        const char* g_name,
+                                        const Grid_Generator& g) const {
   throw_dimension_incompatible(method, g_name, g.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* g_name,
-					const Generator& g) const {
+                                        const char* g_name,
+                                        const Generator& g) const {
   throw_dimension_incompatible(method, g_name, g.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* cgs_name,
-					const Congruence_System& cgs) const {
+                                        const char* cgs_name,
+                                        const Congruence_System& cgs) const {
   throw_dimension_incompatible(method, cgs_name, cgs.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* cs_name,
-					const Constraint_System& cs) const {
+                                        const char* cs_name,
+                                        const Constraint_System& cs) const {
   throw_dimension_incompatible(method, cs_name, cs.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* gs_name,
-					const Grid_Generator_System& gs) const {
+                                        const char* gs_name,
+                                        const Grid_Generator_System& gs) const {
   throw_dimension_incompatible(method, gs_name, gs.space_dimension());
 }
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* var_name,
-					const Variable var) const {
+                                        const char* var_name,
+                                        const Variable var) const {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "this->space_dimension() == " << space_dimension() << ", "
@@ -796,7 +798,7 @@ PPL::Grid::throw_dimension_incompatible(const char* method,
 void
 PPL::Grid::
 throw_dimension_incompatible(const char* method,
-			     dimension_type required_space_dim) const {
+                             dimension_type required_space_dim) const {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "this->space_dimension() == " << space_dimension()
@@ -806,7 +808,7 @@ throw_dimension_incompatible(const char* method,
 
 void
 PPL::Grid::throw_invalid_constraint(const char* method,
-				    const char* c_name) {
+                                    const char* c_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << c_name << " is not an equality constraint.";
@@ -815,7 +817,7 @@ PPL::Grid::throw_invalid_constraint(const char* method,
 
 void
 PPL::Grid::throw_invalid_constraints(const char* method,
-				    const char* cs_name) {
+                                    const char* cs_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "the constraint system " << cs_name
@@ -825,7 +827,7 @@ PPL::Grid::throw_invalid_constraints(const char* method,
 
 void
 PPL::Grid::throw_invalid_generator(const char* method,
-				   const char* g_name) {
+                                   const char* g_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "*this is an empty grid and "
@@ -835,7 +837,7 @@ PPL::Grid::throw_invalid_generator(const char* method,
 
 void
 PPL::Grid::throw_invalid_generators(const char* method,
-				    const char* gs_name) {
+                                    const char* gs_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "*this is an empty grid and" << std::endl
