@@ -1,6 +1,6 @@
 /* Utilities for termination analysis: non-inline, non-template functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,8 +22,8 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "termination.defs.hh"
-#include "NNC_Polyhedron.defs.hh"
+#include "termination_defs.hh"
+#include "NNC_Polyhedron_defs.hh"
 
 namespace Parma_Polyhedra_Library {
 
@@ -33,7 +33,7 @@ namespace Termination {
 
 void
 assign_all_inequalities_approximation(const Constraint_System& cs_in,
-				      Constraint_System& cs_out) {
+                                      Constraint_System& cs_out) {
   if (cs_in.has_strict_inequalities() || cs_in.has_equalities()) {
     // Here we have some strict inequality and/or equality constraints:
     // translate them into non-strict inequality constraints.
@@ -42,12 +42,15 @@ assign_all_inequalities_approximation(const Constraint_System& cs_in,
       const Constraint& c = *i;
       if (c.is_equality()) {
         // Insert the two corresponding opposing inequalities.
-        cs_out.insert(Linear_Expression(c) >= 0);
-        cs_out.insert(Linear_Expression(c) <= 0);
+        const Linear_Expression expr(c.expression());
+        cs_out.insert(expr >= 0);
+        cs_out.insert(expr <= 0);
       }
-      else if (c.is_strict_inequality())
+      else if (c.is_strict_inequality()) {
         // Insert the non-strict approximation.
-        cs_out.insert(Linear_Expression(c) >= 0);
+        const Linear_Expression expr(c.expression());
+        cs_out.insert(expr >= 0);
+      }
       else
         // Insert as is.
         cs_out.insert(c);
@@ -61,21 +64,22 @@ assign_all_inequalities_approximation(const Constraint_System& cs_in,
 template <>
 void
 assign_all_inequalities_approximation(const C_Polyhedron& ph,
-				      Constraint_System& cs) {
+                                      Constraint_System& cs) {
   const Constraint_System& ph_cs = ph.minimized_constraints();
   if (ph_cs.has_equalities()) {
     // Translate equalities into inequalities.
     for (Constraint_System::const_iterator i = ph_cs.begin(),
-	   i_end = ph_cs.end(); i != i_end; ++i) {
+           i_end = ph_cs.end(); i != i_end; ++i) {
       const Constraint& c = *i;
       if (c.is_equality()) {
-	// Insert the two corresponding opposing inequalities.
-	cs.insert(Linear_Expression(c) >= 0);
-	cs.insert(Linear_Expression(c) <= 0);
+        // Insert the two corresponding opposing inequalities.
+        const Linear_Expression expr(c.expression());
+        cs.insert(expr >= 0);
+        cs.insert(expr <= 0);
       }
       else
-	// Insert as is.
-	cs.insert(c);
+        // Insert as is.
+        cs.insert(c);
     }
   }
   else
@@ -124,8 +128,8 @@ assign_all_inequalities_approximation(const C_Polyhedron& ph,
 */
 void
 fill_constraint_systems_MS(const Constraint_System& cs,
-			   Constraint_System& cs_out1,
-			   Constraint_System& cs_out2) {
+                           Constraint_System& cs_out1,
+                           Constraint_System& cs_out2) {
   PPL_ASSERT(cs.space_dimension() % 2 == 0);
   const dimension_type n = cs.space_dimension() / 2;
   const dimension_type m = num_constraints(cs);
@@ -144,8 +148,8 @@ fill_constraint_systems_MS(const Constraint_System& cs,
   std::cout << cs << std::endl;
 #endif
 
-  dimension_type y_begin = n+1;
-  dimension_type z_begin = y_begin + ((&cs_out1 == &cs_out2) ? m : 0);
+  const dimension_type y_begin = n+1;
+  const dimension_type z_begin = y_begin + ((&cs_out1 == &cs_out2) ? m : 0);
 
   // Make sure linear expressions have the correct space dimension.
   Linear_Expression y_le;
@@ -158,9 +162,9 @@ fill_constraint_systems_MS(const Constraint_System& cs,
   dimension_type y = y_begin;
   dimension_type z = z_begin;
   for (Constraint_System::const_iterator i = cs.begin(),
-	 cs_end = cs.end(); i != cs_end; ++i) {
-    Variable v_y(y);
-    Variable v_z(z);
+         cs_end = cs.end(); i != cs_end; ++i) {
+    const Variable v_y(y);
+    const Variable v_z(z);
     ++y;
     ++z;
     cs_out1.insert(v_y >= 0);
@@ -173,7 +177,7 @@ fill_constraint_systems_MS(const Constraint_System& cs,
       sub_mul_assign(y_le, b_i, v_y);
       sub_mul_assign(z_le, b_i, v_z);
     }
-    for (Constraint::Expression::const_iterator j = c_i.expression().begin(),
+    for (Constraint::expr_type::const_iterator j = c_i.expression().begin(),
           j_end = c_i.expression().end(); j != j_end; ++j) {
       Coefficient_traits::const_reference a_i_j = *j;
       const Variable v = j.variable();
@@ -338,9 +342,9 @@ fill_constraint_systems_MS(const Constraint_System& cs,
 */
 void
 fill_constraint_system_PR(const Constraint_System& cs_before,
-			  const Constraint_System& cs_after,
-			  Constraint_System& cs_out,
-			  Linear_Expression& le_out) {
+                          const Constraint_System& cs_after,
+                          Constraint_System& cs_out,
+                          Linear_Expression& le_out) {
   PPL_ASSERT(cs_after.space_dimension() % 2 == 0);
   PPL_ASSERT(2*cs_before.space_dimension() == cs_after.space_dimension());
   const dimension_type n = cs_before.space_dimension();
@@ -355,13 +359,13 @@ fill_constraint_system_PR(const Constraint_System& cs_before,
 
   dimension_type row_index = 0;
   for (Constraint_System::const_iterator i = cs_before.begin(),
-	 cs_before_end = cs_before.end();
+         cs_before_end = cs_before.end();
        i != cs_before_end;
        ++i, ++row_index) {
-    Variable u1_i(m + row_index);
-    Variable u2_i(s + row_index);
-    const Constraint::Expression& e_i = i->expression();
-    for (Constraint::Expression::const_iterator
+    const Variable u1_i(m + row_index);
+    const Variable u2_i(s + row_index);
+    const Constraint::expr_type e_i = i->expression();
+    for (Constraint::expr_type::const_iterator
            j = e_i.begin(), j_end = e_i.end(); j != j_end; ++j) {
       Coefficient_traits::const_reference A_ij_B = *j;
       const Variable v = j.variable();
@@ -379,26 +383,26 @@ fill_constraint_system_PR(const Constraint_System& cs_before,
 
   row_index = 0;
   for (Constraint_System::const_iterator i = cs_after.begin(),
-	 cs_after_end = cs_after.end();
+         cs_after_end = cs_after.end();
        i != cs_after_end;
        ++i, ++row_index) {
-    Variable u3_i(row_index);
-    const Constraint::Expression& e_i = i->expression();
-    for (Constraint::Expression::const_iterator
-           i = e_i.lower_bound(Variable(n)),
-           i_end = e_i.end(); i != i_end; ++i) {
-      Coefficient_traits::const_reference A_ij_C = *i;
-      const Variable v = i.variable();
+    const Variable u3_i(row_index);
+    const Constraint::expr_type e_i = i->expression();
+    for (Constraint::expr_type::const_iterator
+           j = e_i.lower_bound(Variable(n)),
+           j_end = e_i.end(); j != j_end; ++j) {
+      Coefficient_traits::const_reference A_ij_C = *j;
+      const Variable v = j.variable();
       // - u3 A_C, in the context of the j-th constraint.
       sub_mul_assign(les_eq[v.id() - n], A_ij_C, u3_i);
       // u3 A_C, in the context of the (j+n)-th constraint.
       add_mul_assign(les_eq[v.id()], A_ij_C, u3_i);
     }
-    for (Constraint::Expression::const_iterator i = e_i.begin(),
-           i_end = e_i.lower_bound(Variable(n)); i != i_end; ++i) {
-      Coefficient_traits::const_reference Ap_ij_C = *i;
+    for (Constraint::expr_type::const_iterator j = e_i.begin(),
+           j_end = e_i.lower_bound(Variable(n)); j != j_end; ++j) {
+      Coefficient_traits::const_reference Ap_ij_C = *j;
       // u3 Ap_C, in the context of the (j+n)-th constraint.
-      add_mul_assign(les_eq[i.variable().id() + n], Ap_ij_C, u3_i);
+      add_mul_assign(les_eq[j.variable().id() + n], Ap_ij_C, u3_i);
     }
     Coefficient_traits::const_reference b_C = e_i.inhomogeneous_term();
     if (b_C != 0)
@@ -429,24 +433,24 @@ fill_constraint_system_PR_original(const Constraint_System& cs,
 
   dimension_type row_index = 0;
   for (Constraint_System::const_iterator i = cs.begin(),
-	 cs_end = cs.end(); i != cs_end; ++i, ++row_index) {
-    const Constraint::Expression& e_i = i->expression();
+         cs_end = cs.end(); i != cs_end; ++i, ++row_index) {
+    const Constraint::expr_type e_i = i->expression();
     const Variable lambda1_i(row_index);
     const Variable lambda2_i(m + row_index);
-    for (Constraint::Expression::const_iterator i = e_i.begin(),
-          i_end = e_i.lower_bound(Variable(n)); i != i_end; ++i) {
-      Coefficient_traits::const_reference Ap_ij = *i;
-      const Variable v = i.variable();
+    for (Constraint::expr_type::const_iterator j = e_i.begin(),
+          j_end = e_i.lower_bound(Variable(n)); j != j_end; ++j) {
+      Coefficient_traits::const_reference Ap_ij = *j;
+      const Variable v = j.variable();
       // lambda_1 A'
       add_mul_assign(les_eq[v.id()], Ap_ij, lambda1_i);
       // lambda_2 A'
       add_mul_assign(les_eq[v.id()+n+n], Ap_ij, lambda2_i);
     }
-    for (Constraint::Expression::const_iterator
-           i = e_i.lower_bound(Variable(n)),
-           i_end = e_i.end(); i != i_end; ++i) {
-      Coefficient_traits::const_reference A_ij = *i;
-      const Variable v = i.variable();
+    for (Constraint::expr_type::const_iterator
+           j = e_i.lower_bound(Variable(n)),
+           j_end = e_i.end(); j != j_end; ++j) {
+      Coefficient_traits::const_reference A_ij = *j;
+      const Variable v = j.variable();
       // (lambda_1 - lambda_2) A
       add_mul_assign(les_eq[v.id()], A_ij, lambda1_i);
       sub_mul_assign(les_eq[v.id()], A_ij, lambda2_i);
@@ -472,7 +476,7 @@ termination_test_MS(const Constraint_System& cs) {
   Constraint_System cs_mip;
   fill_constraint_systems_MS(cs, cs_mip, cs_mip);
 
-  MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
   return mip.is_satisfiable();
 }
 
@@ -481,21 +485,21 @@ one_affine_ranking_function_MS(const Constraint_System& cs, Generator& mu) {
   Constraint_System cs_mip;
   fill_constraint_systems_MS(cs, cs_mip, cs_mip);
 
-  MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
   if (!mip.is_satisfiable())
     return false;
 
-  Generator fp = mip.feasible_point();
+  const Generator fp = mip.feasible_point();
   PPL_ASSERT(fp.is_point());
   const dimension_type n = cs.space_dimension() / 2;
-  Linear_Expression le(fp.expression(), n + 1);
+  const Linear_Expression le(fp.expression(), n + 1);
   mu = point(le, fp.divisor());
   return true;
 }
 
 void
 all_affine_ranking_functions_MS(const Constraint_System& cs,
-				C_Polyhedron& mu_space) {
+                                C_Polyhedron& mu_space) {
   Constraint_System cs_out1;
   Constraint_System cs_out2;
   fill_constraint_systems_MS(cs, cs_out1, cs_out2);
@@ -586,13 +590,13 @@ termination_test_PR_original(const Constraint_System& cs) {
   // Turn minimization problem into satisfiability.
   cs_mip.insert(le_ineq <= -1);
 
-  MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
   return mip.is_satisfiable();
 }
 
 bool
 termination_test_PR(const Constraint_System& cs_before,
-		    const Constraint_System& cs_after) {
+                    const Constraint_System& cs_after) {
   Constraint_System cs_mip;
   Linear_Expression le_ineq;
   fill_constraint_system_PR(cs_before, cs_after, cs_mip, le_ineq);
@@ -617,14 +621,14 @@ termination_test_PR(const Constraint_System& cs_before,
   // Turn minimization problem into satisfiability.
   cs_mip.insert(le_ineq <= -1);
 
-  MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
   return mip.is_satisfiable();
 }
 
 bool
 one_affine_ranking_function_PR(const Constraint_System& cs_before,
-			       const Constraint_System& cs_after,
-			       Generator& mu) {
+                               const Constraint_System& cs_after,
+                               Generator& mu) {
   return Termination_Helpers
     ::one_affine_ranking_function_PR(cs_before, cs_after, mu);
 }
@@ -637,8 +641,8 @@ one_affine_ranking_function_PR_original(const Constraint_System& cs,
 
 void
 all_affine_ranking_functions_PR(const Constraint_System& cs_before,
-				const Constraint_System& cs_after,
-				NNC_Polyhedron& mu_space) {
+                                const Constraint_System& cs_after,
+                                NNC_Polyhedron& mu_space) {
   Termination_Helpers::all_affine_ranking_functions_PR(cs_before, cs_after,
                                                        mu_space);
 }
@@ -683,7 +687,7 @@ Termination_Helpers
   // Turn minimization problem into satisfiability.
   cs_mip.insert(le_ineq <= -1);
 
-  MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip(cs_mip.space_dimension(), cs_mip);
   if (!mip.is_satisfiable())
     return false;
 
@@ -735,7 +739,7 @@ Termination_Helpers
   // Turn minimization problem into satisfiability.
   cs_mip.insert(le_ineq <= -1);
 
-  MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
+  const MIP_Problem mip = MIP_Problem(cs_mip.space_dimension(), cs_mip);
   if (!mip.is_satisfiable())
     return false;
 
@@ -749,7 +753,7 @@ Termination_Helpers
   dimension_type row_index = m;
   for (Constraint_System::const_iterator i = cs.begin(),
          cs_end = cs.end(); i != cs_end; ++i, ++row_index) {
-    Variable lambda_2(row_index);
+    const Variable lambda_2(row_index);
     Coefficient_traits::const_reference fp_i = fp.coefficient(lambda_2);
     if (fp_i != 0)
       le.linear_combine(i->expr, 1, -fp_i, 1, n + 1);
@@ -871,7 +875,7 @@ Termination_Helpers
   NNC_Polyhedron ph(cs_eqs);
   ph.add_constraint(le_ineq < 0);
   // lambda_2 corresponds to space dimensions m, ..., 2*m-1.
-  Variables_Set lambda1(Variable(0), Variable(m-1));
+  const Variables_Set lambda1(Variable(0), Variable(m-1));
   ph.remove_space_dimensions(lambda1);
 
 #if PRINT_DEBUG_INFO
@@ -897,7 +901,7 @@ Termination_Helpers
       dimension_type row_index = 0;
       for (Constraint_System::const_iterator i = cs.begin(),
              cs_end = cs.end(); i != cs_end; ++i, ++row_index) {
-        Variable lambda2_i(row_index);
+        const Variable lambda2_i(row_index);
         Coefficient_traits::const_reference g_i = g.coefficient(lambda2_i);
         if (g_i != 0)
           le.linear_combine(i->expr, 1, -g_i, 1, n + 1);
