@@ -1,6 +1,6 @@
 /* Test the MIP_Problem class.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -34,8 +34,22 @@ test01() {
   return true;
 }
 
+bool
+test02() {
+  Variable A(0);
+  Variable B(1);
+  MIP_Problem mip(1);
+  Generator p1 = mip.optimizing_point();
+  bool ok1 = (p1 == point(0*A));
+  mip.add_space_dimensions_and_embed(1);
+  Generator p2 = mip.optimizing_point();
+  bool ok2 = (p2 == point(0*A + 0*B));
+  return ok1 && ok2;
+}
+
 } // namespace
 
 BEGIN_MAIN
   DO_TEST(test01);
+  DO_TEST(test02);
 END_MAIN
